--------------------------------------------------------------
-- Real Balanced Pantheons
-- Author: Infixo
-- 2019-04-05: Created
-- 2019-06-29: June 2019 Patch changes
-- 2020-06-10: May 2020 Patch changes
--------------------------------------------------------------

/* distribution
							A:759	B:806	C:691
Charming+ 					1:1.9	1:2.1	1:1.8
Breathtaking+				1:4.7	1:5.7	1:4.7
nothing, no mount			1:2.4	1:2.3	1:2.4
nothing, no mount, no river	1:2.9	1:3.0	1:3.0
river						1:4.4	1:4.1	1:4.1
river, nothing				1:11	1:11	1:9
river, nothing, no-mount	1:14	1:13	1:11
river, flatland				1:6.4	1:5.5	1:5.7
river, flatland, nothing  	1:22	1:18	1:16

*/


--------------------------------------------------------------
-- Resource classes for pantheons improving local resources
-- CLASS_GODDESS_OF_FESTIVALS and CLASS_ORAL_TRADITION already exist

INSERT INTO Tags (Tag, Vocabulary) VALUES
('CLASS_GOD_OF_THE_OPEN_SKY', 'RESOURCE_CLASS'),
('CLASS_GOD_OF_THE_SEA',      'RESOURCE_CLASS'),
('CLASS_GODDESS_OF_THE_HUNT', 'RESOURCE_CLASS'),
('CLASS_SUN_GOD',             'RESOURCE_CLASS'),
('CLASS_STONE_CIRCLES',       'RESOURCE_CLASS'),
('CLASS_RELIGIOUS_IDOLS',     'RESOURCE_CLASS');

INSERT INTO TypeTags (Type, Tag) SELECT ResourceType, 'CLASS_GOD_OF_THE_OPEN_SKY' FROM Improvement_ValidResources WHERE ImprovementType = 'IMPROVEMENT_PASTURE';
INSERT INTO TypeTags (Type, Tag) SELECT ResourceType, 'CLASS_GOD_OF_THE_SEA'      FROM Improvement_ValidResources WHERE ImprovementType = 'IMPROVEMENT_FISHING_BOATS';
INSERT INTO TypeTags (Type, Tag) SELECT ResourceType, 'CLASS_GODDESS_OF_THE_HUNT' FROM Improvement_ValidResources WHERE ImprovementType = 'IMPROVEMENT_CAMP'; 
INSERT INTO TypeTags (Type, Tag) SELECT ResourceType, 'CLASS_SUN_GOD'             FROM Improvement_ValidResources WHERE ImprovementType = 'IMPROVEMENT_FARM';
INSERT INTO TypeTags (Type, Tag) SELECT ResourceType, 'CLASS_STONE_CIRCLES'       FROM Improvement_ValidResources WHERE ImprovementType = 'IMPROVEMENT_QUARRY';
INSERT INTO TypeTags (Type, Tag) SELECT ResourceType, 'CLASS_RELIGIOUS_IDOLS'     FROM Improvement_ValidResources WHERE ImprovementType = 'IMPROVEMENT_MINE'
									AND ResourceType IN (SELECT ResourceType FROM Resources WHERE ResourceClassType = 'RESOURCECLASS_LUXURY' OR ResourceClassType = 'RESOURCECLASS_BONUS');

-- 2019-08-30 Goddess of Festivals - must add a tag for all valid resources, the base game doesn't update it
DELETE FROM TypeTags WHERE Tag = 'CLASS_GODDESS_OF_FESTIVALS';
INSERT INTO TypeTags (Type, Tag) SELECT ResourceType, 'CLASS_GODDESS_OF_FESTIVALS' FROM Improvement_ValidResources WHERE ImprovementType = 'IMPROVEMENT_PLANTATION';


--------------------------------------------------------------
-- Some re-usable requirements
-- Unfortunately many of them are not scored properly
/*
Working (tested)
REQUIREMENT_PLOT_ADJACENT_TO_RIVER -- this is actually IsRiver()
REQUIREMENT_PLOT_IS_HILLS
REQUIREMENT_PLOT_HAS_ANY_IMPROVEMENT
REQUIREMENT_PLOT_HAS_ANY_DISTRICT
REQUIREMENT_PLOT_TERRAIN_TYPE_MATCHES
REQUIREMENT_PLOT_FEATURE_TYPE_MATCHES
REQUIREMENT_PLOT_RESOURCE_TYPE_MATCHES
REQUIREMENT_PLOT_RESOURCE_TAG_MATCHES
REQUIREMENT_PLOT_RESOURCE_CLASS_TYPE_MATCHES
REQUIREMENT_PLOT_ADJACENT_DISTRICT_TYPE_MATCHES

Not tested
REQUIREMENT_PLOT_ADJACENT_TERRAIN_TYPE_MATCHES
REQUIREMENT_PLOT_ADJACENT_FEATURE_TYPE_MATCHES
REQUIREMENT_PLOT_ADJACENT_RESOURCE_CLASS_TYPE_MATCHES
REQUIREMENT_PLOT_HAS_ANY_RESOURCE
REQUIREMENT_CITY_HAS_FEATURE
REQUIREMENT_CITY_HAS_X_FEATURE_TYPE

Not working (ignored or always true)
REQUIREMENT_REQUIREMENTSET_IS_MET - cannot use compound requirements
REQUIREMENT_GAME_ERA_IS - ignored
REQUIREMENT_PLOT_IS_MOUNTAIN - ignored
REQUIREMENT_PLOT_IS_LAKE -- not working
REQUIREMENT_PLOT_TERRAIN_CLASS_MATCHES -- not working
REQUIREMENT_PLOT_HAS_ANY_FEATURE - not working
REQUIREMENT_PLOT_FEATURE_TAG_MATCHES - not working
REQUIREMENT_PLOT_RESOURCE_VISIBLE - not working
*/

-- this one is working, however not used
--INSERT INTO Requirements (RequirementId, RequirementType, Inverse) VALUES
--('REQUIRES_PLOT_NOT_ADJACENT_TO_RIVER', 'REQUIREMENT_PLOT_ADJACENT_TO_RIVER', 1);

INSERT OR REPLACE INTO Requirements (RequirementId, RequirementType, Inverse) VALUES
('REQUIRES_ERA_IS_ANCIENT',  'REQUIREMENT_GAME_ERA_IS', 0);
--('REQUIRES_ERA_NOT_ANCIENT', 'REQUIREMENT_GAME_ERA_IS', 1);

INSERT OR REPLACE INTO RequirementArguments (RequirementId, Name, Value) VALUES
('REQUIRES_ERA_IS_ANCIENT',  'EraType', 'ERA_ANCIENT');
--('REQUIRES_ERA_NOT_ANCIENT', 'EraType', 'ERA_ANCIENT');

-- Requirement: city follows a pantheon and era is Ancient
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT', 'REQUIRES_CITY_FOLLOWS_PANTHEON'); -- exists
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT', 'REQUIRES_ERA_IS_ANCIENT');

-- Requirement: city follows a pantheon and era is NOT Ancient
-- this is working, however not needed as "no improvement" is working and used
--INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)	   VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT', 'REQUIREMENTSET_TEST_ALL');
--INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT', 'REQUIRES_CITY_FOLLOWS_PANTHEON');
--INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT', 'REQUIRES_ERA_NOT_ANCIENT');

/* not working - scoring ignores them

INSERT INTO Requirements (RequirementId, RequirementType, Inverse) VALUES
('REQUIRES_PLOT_HAS_NO_VISIBLE_RESOURCE', 'REQUIREMENT_PLOT_RESOURCE_VISIBLE', 1);

INSERT INTO Requirements (RequirementId, RequirementType, Inverse) VALUES
('REQUIRES_PLOT_HAS_NO_FEATURE', 'REQUIREMENT_PLOT_HAS_ANY_FEATURE', 1);
*/

-- Requirements for No: FEATURE_FOREST, FEATURE_JUNGLE, FEATURE_GEOTHERMAL_FISSURE

INSERT OR REPLACE INTO Requirements (RequirementId, RequirementType, Inverse) VALUES
('REQUIRES_PLOT_HAS_NO_FOREST',  'REQUIREMENT_PLOT_FEATURE_TYPE_MATCHES', 1),
('REQUIRES_PLOT_HAS_NO_JUNGLE',  'REQUIREMENT_PLOT_FEATURE_TYPE_MATCHES', 1),
('REQUIRES_PLOT_HAS_NO_MARSH',   'REQUIREMENT_PLOT_FEATURE_TYPE_MATCHES', 1),
('REQUIRES_PLOT_HAS_NO_OASIS',   'REQUIREMENT_PLOT_FEATURE_TYPE_MATCHES', 1),
('REQUIRES_PLOT_HAS_NO_FISSURE', 'REQUIREMENT_PLOT_FEATURE_TYPE_MATCHES', 1);

INSERT OR REPLACE INTO RequirementArguments (RequirementId, Name, Value) VALUES
('REQUIRES_PLOT_HAS_NO_FOREST',  'FeatureType', 'FEATURE_FOREST'),
('REQUIRES_PLOT_HAS_NO_JUNGLE',  'FeatureType', 'FEATURE_JUNGLE'),
('REQUIRES_PLOT_HAS_NO_MARSH',   'FeatureType', 'FEATURE_MARSH'),
('REQUIRES_PLOT_HAS_NO_OASIS',   'FeatureType', 'FEATURE_OASIS'),
('REQUIRES_PLOT_HAS_NO_FISSURE', 'FeatureType', 'FEATURE_GEOTHERMAL_FISSURE');


-- Requirements for a plot to be a specific terrain
-- REQUIRES_PLOT_HAS_TUNDRA
-- REQUIRES_PLOT_HAS_TUNDRA_HILLS
-- PLOT_IS_TUNDRA_HILLS_TERRAIN_REQUIREMENT
-- PLOT_IS_GRASS_HILLS_TERRAIN_REQUIREMENT
-- PLOT_IS_PLAINS_HILLS_TERRAIN_REQUIREMENT
-- PLOT_IS_HILLS_REQUIREMENT (REQUIREMENT_PLOT_IS_HILLS)
-- REQUIRES_PLOT_IS_FLAT (REQUIREMENT_PLOT_IS_HILLS)
-- PLOT_IS_MOUNTAIN	REQUIREMENT_PLOT_IS_MOUNTAIN

INSERT OR REPLACE INTO Requirements (RequirementId, RequirementType, Inverse) VALUES
('REQUIRES_PLOT_IS_HILLS',  'REQUIREMENT_PLOT_IS_HILLS', 0),
('REQUIRES_PLOT_NOT_HILLS', 'REQUIREMENT_PLOT_IS_HILLS', 1),
('REQUIRES_PLOT_IS_MOUNTAIN',  'REQUIREMENT_PLOT_IS_MOUNTAIN', 0),
('REQUIRES_PLOT_NOT_MOUNTAIN', 'REQUIREMENT_PLOT_IS_MOUNTAIN', 1),
('REQUIRES_PLOT_HAS_DISTRICT',    'REQUIREMENT_PLOT_HAS_ANY_DISTRICT', 0),
('REQUIRES_PLOT_HAS_NO_DISTRICT', 'REQUIREMENT_PLOT_HAS_ANY_DISTRICT', 1);



--------------------------------------------------------------
-- BELIEF_FERTILITY_RITES
-- Builder, +1 Food from Palace, 20% growth

-- Base belief changed to +20% growth (from +10%)
UPDATE ModifierArguments SET Value = 20 WHERE ModifierId = 'FERTILITY_RITES_GROWTH';

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
--('BELIEF_FERTILITY_RITES', 'FERTILITY_RITES_PALACE_HOUSING'),
('BELIEF_FERTILITY_RITES', 'FERTILITY_RITES_PALACE_FOOD');

INSERT OR REPLACE INTO Types (Type, Kind) VALUES
--('MODIFIER_ALL_CITIES_ADJUST_BUILDING_HOUSING',      'KIND_MODIFIER'),
('MODIFIER_ALL_CITIES_ADJUST_BUILDING_YIELD_CHANGE', 'KIND_MODIFIER');

INSERT OR REPLACE INTO DynamicModifiers (ModifierType, CollectionType, EffectType) VALUES
--('MODIFIER_ALL_CITIES_ADJUST_BUILDING_HOUSING',      'COLLECTION_ALL_CITIES', 'EFFECT_ADJUST_BUILDING_HOUSING'), -- working ok, not used
('MODIFIER_ALL_CITIES_ADJUST_BUILDING_YIELD_CHANGE', 'COLLECTION_ALL_CITIES', 'EFFECT_ADJUST_BUILDING_YIELD_CHANGE');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
--('FERTILITY_RITES_PALACE_HOUSING', 'MODIFIER_ALL_CITIES_ADJUST_BUILDING_HOUSING',      'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('FERTILITY_RITES_PALACE_FOOD', 'MODIFIER_ALL_CITIES_ADJUST_BUILDING_YIELD_CHANGE', 'CITY_FOLLOWS_PANTHEON_REQUIREMENTS');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
--('FERTILITY_RITES_PALACE_HOUSING', 'Amount', '1'),
('FERTILITY_RITES_PALACE_FOOD', 'BuildingType', 'BUILDING_PALACE'),
('FERTILITY_RITES_PALACE_FOOD', 'YieldType',    'YIELD_FOOD'),
('FERTILITY_RITES_PALACE_FOOD', 'Amount',       '1');



/* 2019-06-29 June Patch adds a Settler, making it ok. Also, scoring seems to working fine.

--------------------------------------------------------------
-- BELIEF_RELIGIOUS_SETTLEMENTS
-- Still low scores. Make 20%.

-- Base belief changed to 20% rate (from 15%)
UPDATE ModifierArguments SET Value = 20 WHERE ModifierId = 'RELIGIOUS_SETTLEMENTS_CULTUREBORDER';

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_RELIGIOUS_SETTLEMENTS', 'RELIGIOUS_SETTLEMENTS_PALACE_CULTURE');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('RELIGIOUS_SETTLEMENTS_PALACE_CULTURE', 'MODIFIER_ALL_CITIES_ADJUST_BUILDING_YIELD_CHANGE', 'CITY_FOLLOWS_PANTHEON_REQUIREMENTS');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('RELIGIOUS_SETTLEMENTS_PALACE_CULTURE', 'BuildingType', 'BUILDING_PALACE'),
('RELIGIOUS_SETTLEMENTS_PALACE_CULTURE', 'YieldType',    'YIELD_CULTURE'),
('RELIGIOUS_SETTLEMENTS_PALACE_CULTURE', 'Amount',       '1');

*/


/* 2019-06-29 Removed in June Patch

--------------------------------------------------------------
-- BELIEF_GODDESS_OF_THE_HARVEST
-- Prime choice. Make it maybe 50% of it.

-- Base belief changed to 50% of yields (from 100%)
UPDATE ModifierArguments SET Value = 50 WHERE ModifierId = 'GODDESS_OF_THE_HARVEST_HARVEST_MODIFIER';
UPDATE ModifierArguments SET Value = 50 WHERE ModifierId = 'GODDESS_OF_THE_HARVEST_REMOVE_FEATURE_MODIFIER';

*/



--------------------------------------------------------------
-- BELIEF_CITY_PATRON_GODDESS
-- +2 Production toward buildings in cities without districts.

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_CITY_PATRON_GODDESS', 'CITY_PATRON_GODDESS_BUILDING_PRODUCTION');

-- SUCCESS - scored as 46 no matter if building is built or not

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION',          'MODIFIER_ALL_PLAYERS_ATTACH_MODIFIER',                     'PLAYER_HAS_PANTHEON_REQUIREMENTS'),
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION_MODIFIER', 'MODIFIER_PLAYER_CITIES_ADJUST_BUILDING_PRODUCTION_CHANGE', 'CITY_HAS_0_SPECIALTY_DISTRICTS_REQUIREMENTS'); -- used by Industrial CSs

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION',          'ModifierId', 'CITY_PATRON_GODDESS_BUILDING_PRODUCTION_MODIFIER'),
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION_MODIFIER', 'Amount',     '2');


/* +2 Production flat to Districts - NOT scored

--EFFECT_ADJUST_CITY_PRODUCTION_DISTRICT MODIFIER_PLAYER_CITIES_ADJUST_DISTRICT_PRODUCTION_CHANGE
INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('CITY_PATRON_GODDESS_DISTRICT_PRODUCTION2',          'MODIFIER_ALL_PLAYERS_ATTACH_MODIFIER',                     'PLAYER_HAS_PANTHEON_REQUIREMENTS'),
('CITY_PATRON_GODDESS_DISTRICT_PRODUCTION_MODIFIER2', 'MODIFIER_PLAYER_CITIES_ADJUST_DISTRICT_PRODUCTION_CHANGE', 'CITY_HAS_0_SPECIALTY_DISTRICTS_REQUIREMENTS'); -- used by Industrial CSs

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('CITY_PATRON_GODDESS_DISTRICT_PRODUCTION2', 'ModifierId', 'CITY_PATRON_GODDESS_DISTRICT_PRODUCTION_MODIFIER2'),
('CITY_PATRON_GODDESS_DISTRICT_PRODUCTION_MODIFIER2', 'Amount', '2');
*/

/* This one is working - extra prod is given - however, it is scored as 0

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',                      'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION_MODIFIER', 'MODIFIER_SINGLE_CITY_ADJUST_BUILDING_PRODUCTION_MODIFIER', 'CITY_HAS_0_SPECIALTY_DISTRICTS_REQUIREMENTS'); -- used by Kilwa

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION', 'ModifierId', 'CITY_PATRON_GODDESS_BUILDING_PRODUCTION_MODIFIER'),
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION_MODIFIER', 'Amount', '25');
*/

/* this one is not working - no extra production is given

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION', 'MODIFIER_ALL_CITIES_ADJUST_BUILDING_PRODUCTION', 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_HAS_0_SPECIALTY_DISTRICTS');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION', 'Amount', '25');
*/

-- Requirement: plot has a resource with a specific tag
--INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_HAS_0_SPECIALTY_DISTRICTS', 'REQUIREMENTSET_TEST_ALL');
--INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId)	VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_HAS_0_SPECIALTY_DISTRICTS', 'REQUIRES_CITY_FOLLOWS_PANTHEON'); -- exists
--INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId)	VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_HAS_0_SPECIALTY_DISTRICTS', 'REQUIRES_CITY_HAS_0_SPECIALTY_DISTRICTS'); -- exists

/* not working - production is not given

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION',          'MODIFIER_ALL_PLAYERS_ATTACH_MODIFIER',              'PLAYER_HAS_PANTHEON_REQUIREMENTS'),
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION_MODIFIER', 'MODIFIER_PLAYER_CITIES_ADJUST_BUILDING_PRODUCTION', 'CITY_HAS_0_SPECIALTY_DISTRICTS_REQUIREMENTS'); -- used by Limes, Monarchy, Veterancy

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION', 'ModifierId', 'CITY_PATRON_GODDESS_BUILDING_PRODUCTION_MODIFIER'),
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION_MODIFIER', 'DistrictType', 'DISTRICT_CITY_CENTER'),
('CITY_PATRON_GODDESS_BUILDING_PRODUCTION_MODIFIER', 'Amount', '50'); -- BuildingType, DistrictType
*/



--------------------------------------------------------------
-- BELIEF_EARTH_GODDESS
-- WARNING! EARTH_GODDESS_APPEAL_FAITH_MODIFIER is broken, it always returns scoring for ALL tiles. Cannot use it.
-- Once it will be fixed: make it for Breathtaking and +2 Faith.
-- New version +1 Faith
-- Terrain: TERRAIN_GRASS_HILLS, TERRAIN_PLAINS_HILLS, TERRAIN_TUNDRA_HILLS
-- No: FEATURE_FOREST, FEATURE_JUNGLE, FEATURE_GEOTHERMAL_FISSURE

/*
-- Base belief changed to +2 Faith from Breathtaking (from +1 Faith from Charming)
UPDATE Modifiers SET SubjectRequirementSetId = 'PLOT_BREATHTAKING_APPEAL' WHERE ModifierId = 'EARTH_GODDESS_APPEAL_FAITH_MODIFIER' AND SubjectRequirementSetId = 'PLOT_CHARMING_APPEAL';
UPDATE ModifierArguments SET Value = 2 WHERE ModifierId = 'EARTH_GODDESS_APPEAL_FAITH_MODIFIER' AND Name = 'Amount';

-- Base belief valid after Ancient era
UPDATE Modifiers SET SubjectRequirementSetId = 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT' WHERE ModifierId = 'EARTH_GODDESS_APPEAL_FAITH';

-- Requirement: plots has Breathtaking appeal
INSERT OR REPLACE INTO RequirementSets (RequirementSetId, RequirementSetType)       VALUES ('PLOT_BREATHTAKING_APPEAL', 'REQUIREMENTSET_TEST_ALL');
INSERT OR REPLACE INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('PLOT_BREATHTAKING_APPEAL', 'REQUIRES_PLOT_BREATHTAKING_APPEAL');
INSERT OR REPLACE INTO Requirements (RequirementId, RequirementType)                VALUES ('REQUIRES_PLOT_BREATHTAKING_APPEAL', 'REQUIREMENT_PLOT_IS_APPEAL_BETWEEN');
INSERT OR REPLACE INTO RequirementArguments (RequirementId, Name, Value)            VALUES ('REQUIRES_PLOT_BREATHTAKING_APPEAL', 'MinimumAppeal', 4);
*/

/* 2020-06-10 The scoring has been FIXED in the May 2020 Patch!
   It is counting only proper tiles within borders AND ignores Mountains!

DELETE FROM BeliefModifiers WHERE BeliefType = 'BELIEF_EARTH_GODDESS'; -- detach Appeal modifier because it is broken
INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_EARTH_GODDESS', 'EARTH_GODDESS_HILLS_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('EARTH_GODDESS_HILLS_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('EARTH_GODDESS_HILLS_FAITH_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_EARTH_GODDESS_FAITH');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('EARTH_GODDESS_HILLS_FAITH', 'ModifierId', 'EARTH_GODDESS_HILLS_FAITH_MODIFIER'),
('EARTH_GODDESS_HILLS_FAITH_MODIFIER', 'YieldType', 'YIELD_FAITH'),
('EARTH_GODDESS_HILLS_FAITH_MODIFIER', 'Amount',    '1');

INSERT INTO RequirementSets (RequirementSetId, RequirementSetType) VALUES
('REQUIREMENTS_EARTH_GODDESS_FAITH', 'REQUIREMENTSET_TEST_ALL');

INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES
('REQUIREMENTS_EARTH_GODDESS_FAITH', 'REQUIRES_PLOT_IS_HILLS'),
('REQUIREMENTS_EARTH_GODDESS_FAITH', 'REQUIRES_PLOT_HAS_NO_DISTRICT'),
('REQUIREMENTS_EARTH_GODDESS_FAITH', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT'),
('REQUIREMENTS_EARTH_GODDESS_FAITH', 'REQUIRES_PLOT_HAS_NO_FOREST'),
('REQUIREMENTS_EARTH_GODDESS_FAITH', 'REQUIRES_PLOT_HAS_NO_JUNGLE'),
('REQUIREMENTS_EARTH_GODDESS_FAITH', 'REQUIRES_PLOT_HAS_NO_FISSURE');

*/

/* 2019-06-29 After the June Patch I am having CTDs from UI text boxes (modifier strings too long?)

--------------------------------------------------------------
-- BELIEF_RIVER_GODDESS
-- +1 faith from flat tiles adjacent to a river
-- River: Yes
-- Terrain: TERRAIN_TUNDRA, TERRAIN_PLAINS, TERRAIN_GRASS
-- No: FEATURE_FOREST, FEATURE_JUNGLE, FEATURE_GEOTHERMAL_FISSURE

--INSERT INTO Types (Type, Kind) VALUES
--('BELIEF_RIVER_GODDESS_PLOTS', 'KIND_BELIEF');

--INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
--('BELIEF_RIVER_GODDESS_PLOTS', 'LOC_BELIEF_RIVER_GODDESS_PLOTS_NAME', 'LOC_BELIEF_RIVER_GODDESS_PLOTS_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_RIVER_GODDESS', 'RIVER_GODDESS_PLAINS_FAITH'),
('BELIEF_RIVER_GODDESS', 'RIVER_GODDESS_GRASS_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('RIVER_GODDESS_PLAINS_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('RIVER_GODDESS_PLAINS_FAITH_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_RIVER_GODDESS_PLAINS'),
('RIVER_GODDESS_GRASS_FAITH',           'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('RIVER_GODDESS_GRASS_FAITH_MODIFIER',  'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_RIVER_GODDESS_GRASS');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('RIVER_GODDESS_PLAINS_FAITH', 'ModifierId', 'RIVER_GODDESS_PLAINS_FAITH_MODIFIER'),
('RIVER_GODDESS_GRASS_FAITH',  'ModifierId', 'RIVER_GODDESS_GRASS_FAITH_MODIFIER'),
('RIVER_GODDESS_PLAINS_FAITH_MODIFIER', 'YieldType', 'YIELD_FAITH'),
('RIVER_GODDESS_PLAINS_FAITH_MODIFIER', 'Amount',    '1'),
('RIVER_GODDESS_GRASS_FAITH_MODIFIER',  'YieldType', 'YIELD_FAITH'),
('RIVER_GODDESS_GRASS_FAITH_MODIFIER',  'Amount',    '1');

INSERT INTO RequirementSets (RequirementSetId, RequirementSetType) VALUES
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIREMENTSET_TEST_ALL'),
('REQUIREMENTS_RIVER_GODDESS_GRASS',  'REQUIREMENTSET_TEST_ALL');

INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIRES_PLOT_IS_PLAINS'),
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIRES_PLOT_ADJACENT_TO_RIVER'),
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIRES_PLOT_HAS_NO_DISTRICT'),
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT'),
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIRES_PLOT_HAS_NO_FOREST'),
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIRES_PLOT_HAS_NO_JUNGLE'),
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIRES_PLOT_HAS_NO_MARSH'),
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIRES_PLOT_HAS_NO_OASIS'),
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIRES_PLOT_HAS_NO_FLOODPLAINS'), -- exists
('REQUIREMENTS_RIVER_GODDESS_PLAINS', 'REQUIRES_PLOT_HAS_NO_FISSURE'),
('REQUIREMENTS_RIVER_GODDESS_GRASS', 'REQUIRES_PLOT_IS_GRASS'),
('REQUIREMENTS_RIVER_GODDESS_GRASS', 'REQUIRES_PLOT_ADJACENT_TO_RIVER'),
('REQUIREMENTS_RIVER_GODDESS_GRASS', 'REQUIRES_PLOT_HAS_NO_DISTRICT'),
('REQUIREMENTS_RIVER_GODDESS_GRASS', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT'),
('REQUIREMENTS_RIVER_GODDESS_GRASS', 'REQUIRES_PLOT_HAS_NO_FOREST'),
('REQUIREMENTS_RIVER_GODDESS_GRASS', 'REQUIRES_PLOT_HAS_NO_JUNGLE'),
('REQUIREMENTS_RIVER_GODDESS_GRASS', 'REQUIRES_PLOT_HAS_NO_MARSH'),
('REQUIREMENTS_RIVER_GODDESS_GRASS', 'REQUIRES_PLOT_HAS_NO_OASIS'),
('REQUIREMENTS_RIVER_GODDESS_GRASS', 'REQUIRES_PLOT_HAS_NO_FLOODPLAINS'), -- exists
('REQUIREMENTS_RIVER_GODDESS_GRASS', 'REQUIRES_PLOT_HAS_NO_FISSURE');

-- Requirement: plot is a specific terrain
INSERT OR REPLACE INTO Requirements (RequirementId, RequirementType)     VALUES ('REQUIRES_PLOT_IS_PLAINS', 'REQUIREMENT_PLOT_TERRAIN_TYPE_MATCHES');
INSERT OR REPLACE INTO RequirementArguments (RequirementId, Name, Value) VALUES ('REQUIRES_PLOT_IS_PLAINS', 'TerrainType', 'TERRAIN_PLAINS');
INSERT OR REPLACE INTO Requirements (RequirementId, RequirementType)     VALUES ('REQUIRES_PLOT_IS_GRASS',  'REQUIREMENT_PLOT_TERRAIN_TYPE_MATCHES');
INSERT OR REPLACE INTO RequirementArguments (RequirementId, Name, Value) VALUES ('REQUIRES_PLOT_IS_GRASS',  'TerrainType', 'TERRAIN_GRASS');

-- doesn't work
--INSERT INTO Requirements (RequirementId, RequirementType, Inverse) VALUES
--('REQUIRES_PLOT_HAS_NO_RESOURCE', 'REQUIREMENT_PLOT_HAS_ANY_RESOURCE', 1);

*/



--------------------------------------------------------------
-- BELIEF_GOD_OF_THE_SEA
-- +1 Production from Fishing Boats resources

-- Base belief valid after Ancient era
--UPDATE Modifiers SET SubjectRequirementSetId = 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT' WHERE ModifierId = 'GOD_OF_THE_SEA_FISHINGBOATS_PRODUCTION';

--INSERT INTO Types (Type, Kind) VALUES
--('BELIEF_GOD_OF_THE_SEA_RESOURCES', 'KIND_BELIEF');

--INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
--('BELIEF_GOD_OF_THE_SEA_RESOURCES', 'LOC_BELIEF_GOD_OF_THE_SEA_RESOURCES_NAME', 'LOC_BELIEF_GOD_OF_THE_SEA_RESOURCES_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_GOD_OF_THE_SEA', 'GOD_OF_THE_SEA_RESOURCES_PRODUCTION'),
('BELIEF_GOD_OF_THE_SEA', 'GOD_OF_THE_SEA_COAST_GROWTH'),
('BELIEF_GOD_OF_THE_SEA', 'GOD_OF_THE_SEA_COAST_BORDER');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
--('GOD_OF_THE_SEA_RESOURCES_PRODUCTION',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',          'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('GOD_OF_THE_SEA_RESOURCES_PRODUCTION',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',          'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('GOD_OF_THE_SEA_RESOURCES_PRODUCTION_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD',  'REQUIREMENTS_GOD_OF_THE_SEA_RESOURCES'),
('GOD_OF_THE_SEA_COAST_GROWTH',                  'MODIFIER_ALL_CITIES_ADJUST_CITY_GROWTH',       'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_COASTAL'),
('GOD_OF_THE_SEA_COAST_BORDER',                  'MODIFIER_ALL_CITIES_CULTURE_BORDER_EXPANSION', 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_COASTAL');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('GOD_OF_THE_SEA_RESOURCES_PRODUCTION', 'ModifierId', 'GOD_OF_THE_SEA_RESOURCES_PRODUCTION_MODIFIER'),
('GOD_OF_THE_SEA_RESOURCES_PRODUCTION_MODIFIER', 'YieldType', 'YIELD_PRODUCTION'),
('GOD_OF_THE_SEA_RESOURCES_PRODUCTION_MODIFIER', 'Amount',    '1'),
('GOD_OF_THE_SEA_COAST_GROWTH',                  'Amount',   '10'),
('GOD_OF_THE_SEA_COAST_BORDER',                  'Amount',   '10');

-- Requirement: plot has a resource with a specific tag
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_GOD_OF_THE_SEA_RESOURCES', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_THE_SEA_RESOURCES', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_THE_SEA_RESOURCES', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_THE_SEA_RESOURCES', 'REQUIRES_PLOT_HAS_TAG_GOD_OF_THE_SEA');
INSERT INTO Requirements (RequirementId, RequirementType)				 VALUES ('REQUIRES_PLOT_HAS_TAG_GOD_OF_THE_SEA',  'REQUIREMENT_PLOT_RESOURCE_TAG_MATCHES');
INSERT INTO RequirementArguments (RequirementId, Name, Value)			 VALUES ('REQUIRES_PLOT_HAS_TAG_GOD_OF_THE_SEA',  'Tag', 'CLASS_GOD_OF_THE_SEA');

-- Requirement: city follows a pantheon and is coastal
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_COASTAL', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_COASTAL', 'REQUIRES_CITY_FOLLOWS_PANTHEON');
-- not working for scoring (always true), but this is the ONLY way to check for Coastal Cities
-- I will leave it because the scoring for 10% growth and border is low, so without access to actual sea resources this pantheon will not be chosen anyway
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_CITY_FOLLOWS_PANTHEON_COASTAL', 'PLOT_IS_COASTAL_LAND_XP2'); -- exists 



--------------------------------------------------------------
-- BELIEF_GOD_OF_THE_OPEN_SKY
-- +1 Culture from Pasture resources

-- Base belief valid after Ancient era
--UPDATE Modifiers SET SubjectRequirementSetId = 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT' WHERE ModifierId = 'GOD_OF_THE_OPEN_SKY_PASTURE_CULTURE';

--INSERT INTO Types (Type, Kind) VALUES
--('BELIEF_GOD_OF_THE_OPEN_SKY_RESOURCES', 'KIND_BELIEF');

--INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
--('BELIEF_GOD_OF_THE_OPEN_SKY_RESOURCES', 'LOC_BELIEF_GOD_OF_THE_OPEN_SKY_RESOURCES_NAME', 'LOC_BELIEF_GOD_OF_THE_OPEN_SKY_RESOURCES_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_GOD_OF_THE_OPEN_SKY', 'GOD_OF_THE_OPEN_SKY_RESOURCES_CULTURE');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
--('GOD_OF_THE_OPEN_SKY_RESOURCES_CULTURE',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('GOD_OF_THE_OPEN_SKY_RESOURCES_CULTURE',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',          'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('GOD_OF_THE_OPEN_SKY_RESOURCES_CULTURE_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_GOD_OF_THE_OPEN_SKY_RESOURCES');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('GOD_OF_THE_OPEN_SKY_RESOURCES_CULTURE', 'ModifierId', 'GOD_OF_THE_OPEN_SKY_RESOURCES_CULTURE_MODIFIER'),
('GOD_OF_THE_OPEN_SKY_RESOURCES_CULTURE_MODIFIER', 'YieldType', 'YIELD_CULTURE'),
('GOD_OF_THE_OPEN_SKY_RESOURCES_CULTURE_MODIFIER', 'Amount',    '1');

-- Requirement: plot has a resource with a specific tag
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_GOD_OF_THE_OPEN_SKY_RESOURCES', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_THE_OPEN_SKY_RESOURCES', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_THE_OPEN_SKY_RESOURCES', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_THE_OPEN_SKY_RESOURCES', 'REQUIRES_PLOT_HAS_TAG_GOD_OF_THE_OPEN_SKY');
INSERT INTO Requirements (RequirementId, RequirementType)				 VALUES ('REQUIRES_PLOT_HAS_TAG_GOD_OF_THE_OPEN_SKY',  'REQUIREMENT_PLOT_RESOURCE_TAG_MATCHES');
INSERT INTO RequirementArguments (RequirementId, Name, Value)			 VALUES ('REQUIRES_PLOT_HAS_TAG_GOD_OF_THE_OPEN_SKY',  'Tag', 'CLASS_GOD_OF_THE_OPEN_SKY');



--------------------------------------------------------------
-- BELIEF_GODDESS_OF_THE_HUNT
-- +1 Food & +1 Prod from Camp resources

-- Base belief changed to +2 Food (from +1)
-- 2019-06-29 Not needed after June Patch
--UPDATE ModifierArguments SET Value = 2 WHERE ModifierId = 'GODDESS_OF_THE_HUNT_CAMP_FOOD_MODIFIER' AND Name = 'Amount';

-- Base belief valid after Ancient era
--UPDATE Modifiers SET SubjectRequirementSetId = 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT' WHERE ModifierId = 'GODDESS_OF_THE_HUNT_CAMP_FOOD';

--INSERT INTO Types (Type, Kind) VALUES
--('BELIEF_GODDESS_OF_THE_HUNT_RESOURCES', 'KIND_BELIEF');

--INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
--('BELIEF_GODDESS_OF_THE_HUNT_RESOURCES', 'LOC_BELIEF_GODDESS_OF_THE_HUNT_RESOURCES_NAME', 'LOC_BELIEF_GODDESS_OF_THE_HUNT_RESOURCES_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_GODDESS_OF_THE_HUNT', 'GODDESS_OF_THE_HUNT_RESOURCES_FOOD'),
 -- 2019-06-29 June Patch
('BELIEF_GODDESS_OF_THE_HUNT', 'GODDESS_OF_THE_HUNT_RESOURCES_PRODUCTION');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
--('GODDESS_OF_THE_HUNT_RESOURCES_FOOD',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('GODDESS_OF_THE_HUNT_RESOURCES_FOOD',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',          'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('GODDESS_OF_THE_HUNT_RESOURCES_FOOD_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_GODDESS_OF_THE_HUNT_RESOURCES'),
-- 2019-06-29 June Patch
--('GODDESS_OF_THE_HUNT_RESOURCES_PRODUCTION',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('GODDESS_OF_THE_HUNT_RESOURCES_PRODUCTION',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',          'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('GODDESS_OF_THE_HUNT_RESOURCES_PRODUCTION_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_GODDESS_OF_THE_HUNT_RESOURCES');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('GODDESS_OF_THE_HUNT_RESOURCES_FOOD', 'ModifierId', 'GODDESS_OF_THE_HUNT_RESOURCES_FOOD_MODIFIER'),
('GODDESS_OF_THE_HUNT_RESOURCES_FOOD_MODIFIER', 'YieldType', 'YIELD_FOOD'),
('GODDESS_OF_THE_HUNT_RESOURCES_FOOD_MODIFIER', 'Amount',    '1'),
-- 2019-06-29 June Patch
('GODDESS_OF_THE_HUNT_RESOURCES_PRODUCTION', 'ModifierId', 'GODDESS_OF_THE_HUNT_RESOURCES_PRODUCTION_MODIFIER'),
('GODDESS_OF_THE_HUNT_RESOURCES_PRODUCTION_MODIFIER', 'YieldType', 'YIELD_PRODUCTION'),
('GODDESS_OF_THE_HUNT_RESOURCES_PRODUCTION_MODIFIER', 'Amount',    '1');

-- Requirement: plot has a resource with a specific tag
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_GODDESS_OF_THE_HUNT_RESOURCES', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GODDESS_OF_THE_HUNT_RESOURCES', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GODDESS_OF_THE_HUNT_RESOURCES', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GODDESS_OF_THE_HUNT_RESOURCES', 'REQUIRES_PLOT_HAS_TAG_GODDESS_OF_THE_HUNT');
INSERT INTO Requirements (RequirementId, RequirementType)				 VALUES ('REQUIRES_PLOT_HAS_TAG_GODDESS_OF_THE_HUNT',  'REQUIREMENT_PLOT_RESOURCE_TAG_MATCHES');
INSERT INTO RequirementArguments (RequirementId, Name, Value)			 VALUES ('REQUIRES_PLOT_HAS_TAG_GODDESS_OF_THE_HUNT',  'Tag', 'CLASS_GODDESS_OF_THE_HUNT');



--------------------------------------------------------------
-- BELIEF_STONE_CIRCLES
-- +2 Faith from Quarry resources

-- Base belief valid after Ancient era
--UPDATE Modifiers SET SubjectRequirementSetId = 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT' WHERE ModifierId = 'STONE_CIRCLES_QUARRY_FAITH';

--INSERT INTO Types (Type, Kind) VALUES
--('BELIEF_STONE_CIRCLES_RESOURCES', 'KIND_BELIEF');

--INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
--('BELIEF_STONE_CIRCLES_RESOURCES', 'LOC_BELIEF_STONE_CIRCLES_RESOURCES_NAME', 'LOC_BELIEF_STONE_CIRCLES_RESOURCES_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_STONE_CIRCLES', 'STONE_CIRCLES_RESOURCES_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
--('STONE_CIRCLES_RESOURCES_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('STONE_CIRCLES_RESOURCES_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',          'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('STONE_CIRCLES_RESOURCES_FAITH_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_STONE_CIRCLES_RESOURCES');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('STONE_CIRCLES_RESOURCES_FAITH', 'ModifierId', 'STONE_CIRCLES_RESOURCES_FAITH_MODIFIER'),
('STONE_CIRCLES_RESOURCES_FAITH_MODIFIER', 'YieldType', 'YIELD_FAITH'),
('STONE_CIRCLES_RESOURCES_FAITH_MODIFIER', 'Amount',    '2');

-- Requirement: plot has a resource with a specific tag
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_STONE_CIRCLES_RESOURCES', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_STONE_CIRCLES_RESOURCES', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_STONE_CIRCLES_RESOURCES', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_STONE_CIRCLES_RESOURCES', 'REQUIRES_PLOT_HAS_TAG_STONE_CIRCLES');
INSERT INTO Requirements (RequirementId, RequirementType)				 VALUES ('REQUIRES_PLOT_HAS_TAG_STONE_CIRCLES',  'REQUIREMENT_PLOT_RESOURCE_TAG_MATCHES');
INSERT INTO RequirementArguments (RequirementId, Name, Value)			 VALUES ('REQUIRES_PLOT_HAS_TAG_STONE_CIRCLES',  'Tag', 'CLASS_STONE_CIRCLES');



--------------------------------------------------------------
-- BELIEF_RELIGIOUS_IDOLS
-- +2 Faith from Mines over Luxury and Bonus resources.

-- Base belief valid after Ancient era
--UPDATE Modifiers SET SubjectRequirementSetId = 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT' WHERE ModifierId = 'RELIGIOUS_IDOLS_BONUS_MINE_FAITH';
--UPDATE Modifiers SET SubjectRequirementSetId = 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT' WHERE ModifierId = 'RELIGIOUS_IDOLS_LUXURY_MINE_FAITH';

--INSERT INTO Types (Type, Kind) VALUES
--('BELIEF_RELIGIOUS_IDOLS_RESOURCES', 'KIND_BELIEF');

--INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
--('BELIEF_RELIGIOUS_IDOLS_RESOURCES', 'LOC_BELIEF_RELIGIOUS_IDOLS_RESOURCES_NAME', 'LOC_BELIEF_RELIGIOUS_IDOLS_RESOURCES_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_RELIGIOUS_IDOLS', 'RELIGIOUS_IDOLS_RESOURCES_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
--('RELIGIOUS_IDOLS_RESOURCES_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('RELIGIOUS_IDOLS_RESOURCES_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',          'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('RELIGIOUS_IDOLS_RESOURCES_FAITH_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_RELIGIOUS_IDOLS_RESOURCES');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('RELIGIOUS_IDOLS_RESOURCES_FAITH', 'ModifierId', 'RELIGIOUS_IDOLS_RESOURCES_FAITH_MODIFIER'),
('RELIGIOUS_IDOLS_RESOURCES_FAITH_MODIFIER', 'YieldType', 'YIELD_FAITH'),
('RELIGIOUS_IDOLS_RESOURCES_FAITH_MODIFIER', 'Amount',    '2');

-- Requirement: plot has a resource with a specific tag
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_RELIGIOUS_IDOLS_RESOURCES', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_RELIGIOUS_IDOLS_RESOURCES', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_RELIGIOUS_IDOLS_RESOURCES', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_RELIGIOUS_IDOLS_RESOURCES', 'REQUIRES_PLOT_HAS_TAG_RELIGIOUS_IDOLS');
INSERT INTO Requirements (RequirementId, RequirementType)				 VALUES ('REQUIRES_PLOT_HAS_TAG_RELIGIOUS_IDOLS',  'REQUIREMENT_PLOT_RESOURCE_TAG_MATCHES');
INSERT INTO RequirementArguments (RequirementId, Name, Value)			 VALUES ('REQUIRES_PLOT_HAS_TAG_RELIGIOUS_IDOLS',  'Tag', 'CLASS_RELIGIOUS_IDOLS');



--------------------------------------------------------------
-- BELIEF_GOD_OF_CRAFTSMEN
-- +1 Production from Forest and Lumber Mills

--INSERT INTO Types (Type, Kind) VALUES
--('BELIEF_GOD_OF_CRAFTSMEN_POPULATION', 'KIND_BELIEF');

--INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
--('BELIEF_GOD_OF_CRAFTSMEN_POPULATION', 'LOC_BELIEF_GOD_OF_CRAFTSMEN_POPULATION_NAME', 'LOC_BELIEF_GOD_OF_CRAFTSMEN_POPULATION_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

-- 2019-06-29 June Patch
DELETE FROM BeliefModifiers WHERE BeliefType = 'BELIEF_GOD_OF_CRAFTSMEN'; -- detach original modifiers because they are not scored properly

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
--('BELIEF_GOD_OF_CRAFTSMEN', 'GOD_OF_CRAFTSMEN_MILL_PRODUCTION'), -- 2019-06-29 June Patch
('BELIEF_GOD_OF_CRAFTSMEN', 'GOD_OF_CRAFTSMEN_FOREST_PRODUCTION');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
--('GOD_OF_CRAFTSMEN_MILL_PRODUCTION',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),  -- 2019-06-29 June Patch
--('GOD_OF_CRAFTSMEN_MILL_PRODUCTION_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_GOD_OF_CRAFTSMEN_MILL'),
--('GOD_OF_CRAFTSMEN_FOREST_PRODUCTION',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('GOD_OF_CRAFTSMEN_FOREST_PRODUCTION',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',          'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('GOD_OF_CRAFTSMEN_FOREST_PRODUCTION_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_GOD_OF_CRAFTSMEN_FOREST');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
--('GOD_OF_CRAFTSMEN_MILL_PRODUCTION', 'ModifierId', 'GOD_OF_CRAFTSMEN_MILL_PRODUCTION_MODIFIER'),  -- 2019-06-29 June Patch
--('GOD_OF_CRAFTSMEN_MILL_PRODUCTION_MODIFIER', 'YieldType', 'YIELD_PRODUCTION'),
--('GOD_OF_CRAFTSMEN_MILL_PRODUCTION_MODIFIER', 'Amount',    '1'),
('GOD_OF_CRAFTSMEN_FOREST_PRODUCTION', 'ModifierId', 'GOD_OF_CRAFTSMEN_FOREST_PRODUCTION_MODIFIER'),
('GOD_OF_CRAFTSMEN_FOREST_PRODUCTION_MODIFIER', 'YieldType', 'YIELD_PRODUCTION'),
('GOD_OF_CRAFTSMEN_FOREST_PRODUCTION_MODIFIER', 'Amount',    '1');

-- Requirement: plot has only forest and is adjacent to the city center
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_GOD_OF_CRAFTSMEN_FOREST', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_CRAFTSMEN_FOREST', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_CRAFTSMEN_FOREST', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_CRAFTSMEN_FOREST', 'PLOT_IS_FOREST_REQUIREMENT'); -- exists
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_CRAFTSMEN_FOREST', 'REQUIRES_PLOT_ADJACENT_TO_CITY_CENTER');
INSERT OR REPLACE INTO Requirements (RequirementId, RequirementType)	 VALUES ('REQUIRES_PLOT_ADJACENT_TO_CITY_CENTER', 'REQUIREMENT_PLOT_ADJACENT_DISTRICT_TYPE_MATCHES');
INSERT OR REPLACE INTO RequirementArguments (RequirementId, Name, Value) VALUES ('REQUIRES_PLOT_ADJACENT_TO_CITY_CENTER', 'DistrictType', 'DISTRICT_CITY_CENTER');

-- Requirement: plot has lumber mill
-- 2019-06-29 June Patch
--INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_GOD_OF_CRAFTSMEN_MILL', 'REQUIREMENTSET_TEST_ALL');
--INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_CRAFTSMEN_MILL', 'REQUIRES_PLOT_HAS_LUMBER_MILL');
--INSERT OR REPLACE INTO Requirements (RequirementId, RequirementType)     VALUES ('REQUIRES_PLOT_HAS_LUMBER_MILL', 'REQUIREMENT_PLOT_IMPROVEMENT_TYPE_MATCHES');
--INSERT OR REPLACE INTO RequirementArguments (RequirementId, Name, Value) VALUES ('REQUIRES_PLOT_HAS_LUMBER_MILL', 'ImprovementType', 'IMPROVEMENT_LUMBER_MILL');

-- 2019-06-29 June Patch
-- +1 Production and +1 Faith from Improved Strategic resources
-- replaces original modifier because its scoring is broken

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_GOD_OF_CRAFTSMEN', 'GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_PRODUCTION'),
('BELIEF_GOD_OF_CRAFTSMEN', 'GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_PRODUCTION',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_PRODUCTION_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC'),
('GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_FAITH_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_PRODUCTION', 'ModifierId', 'GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_PRODUCTION_MODIFIER'),
('GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_PRODUCTION_MODIFIER', 'YieldType', 'YIELD_PRODUCTION'),
('GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_PRODUCTION_MODIFIER', 'Amount',    '1'),
('GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_FAITH', 'ModifierId', 'GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_FAITH_MODIFIER'),
('GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_FAITH_MODIFIER', 'YieldType', 'YIELD_FAITH'),
('GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC_FAITH_MODIFIER', 'Amount',    '1');

-- Requirement: plot has improved strategic resource
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC', 'REQUIRES_PLOT_HAS_STRATEGIC'); -- exists
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GOD_OF_CRAFTSMEN_IMPROVED_STRATEGIC', 'REQUIRES_PLOT_HAS_IMPROVEMENT');
INSERT OR REPLACE INTO Requirements (RequirementId, RequirementType)     VALUES ('REQUIRES_PLOT_HAS_IMPROVEMENT', 'REQUIREMENT_PLOT_HAS_ANY_IMPROVEMENT');


/* not scored properly
-- 0.2-0.4 prod/gold from Population
-- Valuation is always 0 for Amount < 1.0

INSERT OR REPLACE INTO Types (Type, Kind) VALUES
('MODIFIER_ALL_CITIES_ADJUST_CITY_YIELD_PER_POPULATION', 'KIND_MODIFIER');

INSERT OR REPLACE INTO DynamicModifiers (ModifierType, CollectionType, EffectType) VALUES
('MODIFIER_ALL_CITIES_ADJUST_CITY_YIELD_PER_POPULATION', 'COLLECTION_ALL_CITIES', 'EFFECT_ADJUST_CITY_YIELD_PER_POPULATION');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('GOD_OF_CRAFTSMEN_POPULATION_PRODUCTION', 'MODIFIER_ALL_CITIES_ADJUST_CITY_YIELD_PER_POPULATION', 'CITY_FOLLOWS_PANTHEON_REQUIREMENTS');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('GOD_OF_CRAFTSMEN_POPULATION_PRODUCTION', 'YieldType', 'YIELD_PRODUCTION'),
('GOD_OF_CRAFTSMEN_POPULATION_PRODUCTION', 'Amount',    '0.5');
*/



--------------------------------------------------------------
-- BELIEF_GODDESS_OF_FESTIVALS
-- +1 Culture from Plantations.
-- 2019-06-29 June Patch, merged with Oral Tradition

-- Base belief valid after Ancient era
--UPDATE Modifiers SET SubjectRequirementSetId = 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT' WHERE ModifierId = 'GODDESS_OF_FESTIVALS_PLANTATION_TAG_FOOD';

--INSERT INTO Types (Type, Kind) VALUES
--('BELIEF_GODDESS_OF_FESTIVALS_RESOURCES', 'KIND_BELIEF');

--INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
--('BELIEF_GODDESS_OF_FESTIVALS_RESOURCES', 'LOC_BELIEF_GODDESS_OF_FESTIVALS_IDOLS_RESOURCES_NAME', 'LOC_BELIEF_GODDESS_OF_FESTIVALS_RESOURCES_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_GODDESS_OF_FESTIVALS', 'GODDESS_OF_FESTIVALS_RESOURCES_CULTURE');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
--('GODDESS_OF_FESTIVALS_RESOURCES_CULTURE',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('GODDESS_OF_FESTIVALS_RESOURCES_CULTURE',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',          'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('GODDESS_OF_FESTIVALS_RESOURCES_CULTURE_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_GODDESS_OF_FESTIVALS_RESOURCES');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('GODDESS_OF_FESTIVALS_RESOURCES_CULTURE', 'ModifierId', 'GODDESS_OF_FESTIVALS_RESOURCES_CULTURE_MODIFIER'),
('GODDESS_OF_FESTIVALS_RESOURCES_CULTURE_MODIFIER', 'YieldType', 'YIELD_CULTURE'),
('GODDESS_OF_FESTIVALS_RESOURCES_CULTURE_MODIFIER', 'Amount',    '1');

-- Requirement: plot has a resource with a specific tag
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_GODDESS_OF_FESTIVALS_RESOURCES', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GODDESS_OF_FESTIVALS_RESOURCES', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GODDESS_OF_FESTIVALS_RESOURCES', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_GODDESS_OF_FESTIVALS_RESOURCES', 'REQUIRES_PLOT_HAS_TAG_GODDESS_OF_FESTIVAL'); -- exists



/* 2019-06-29 June Patch removes it

--------------------------------------------------------------
-- BELIEF_ORAL_TRADITION_RESOURCES
-- +1 [ICON_Culture] Culture from [ICON_RESOURCE_BANANAS] Banana, [ICON_RESOURCE_CITRUS] Citrus, [ICON_RESOURCE_COTTON] Cotton, [ICON_RESOURCE_DYES] Dyes, [ICON_RESOURCE_SILK] Silk, [ICON_RESOURCE_SPICES] Spices, and [ICON_RESOURCE_SUGAR] Sugar Plantations.

-- Base belief valid after Ancient era
--UPDATE Modifiers SET SubjectRequirementSetId = 'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_NOT_ANCIENT' WHERE ModifierId = 'ORAL_TRADITION_PLANTATION_TAG_CULTURE';

--INSERT INTO Types (Type, Kind) VALUES
--('BELIEF_ORAL_TRADITION_RESOURCES', 'KIND_BELIEF');

--INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
--('BELIEF_ORAL_TRADITION_RESOURCES', 'LOC_BELIEF_ORAL_TRADITION_RESOURCES_NAME', 'LOC_BELIEF_ORAL_TRADITION_RESOURCES_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_ORAL_TRADITION', 'ORAL_TRADITION_RESOURCES_CULTURE');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('ORAL_TRADITION_RESOURCES_CULTURE',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('ORAL_TRADITION_RESOURCES_CULTURE_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_ORAL_TRADITION_RESOURCES');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('ORAL_TRADITION_RESOURCES_CULTURE', 'ModifierId', 'ORAL_TRADITION_RESOURCES_CULTURE_MODIFIER'),
('ORAL_TRADITION_RESOURCES_CULTURE_MODIFIER', 'YieldType', 'YIELD_CULTURE'),
('ORAL_TRADITION_RESOURCES_CULTURE_MODIFIER', 'Amount',    '1');

-- Requirement: plot has a resource with a specific tag
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_ORAL_TRADITION_RESOURCES', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_ORAL_TRADITION_RESOURCES', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_ORAL_TRADITION_RESOURCES', 'REQUIRES_PLOT_HAS_TAG_ORAL_TRADITION'); -- exists
*/


--------------------------------------------------------------
-- BELIEF_MONUMENT_TO_THE_GODS
-- Yields for the Palace
-- WARNING! MONUMENT_TO_THE_GODS_ANCIENTCLASSICALWONDER is broken - adding it to a Pantheon resets its scoring to 0!
-- Cannot find any other modifier to replace it, none that increase Wonder production actually works

/*
INSERT INTO Types (Type, Kind) VALUES
('BELIEF_GOD_KING', 'KIND_BELIEF');

INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
('BELIEF_GOD_KING', 'LOC_BELIEF_GOD_KING_NAME', 'LOC_BELIEF_GOD_KING_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
--('BELIEF_MONUMENT_TO_THE_GODS', 'MONUMENT_TO_THE_GODS_PALACE_PRODUCTION'),
--('BELIEF_MONUMENT_TO_THE_GODS', 'MONUMENT_TO_THE_GODS_PALACE_FAITH');
('BELIEF_GOD_KING', 'MONUMENT_TO_THE_GODS_PALACE_PRODUCTION'),
('BELIEF_GOD_KING', 'MONUMENT_TO_THE_GODS_PALACE_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('MONUMENT_TO_THE_GODS_PALACE_PRODUCTION', 'MODIFIER_ALL_CITIES_ADJUST_BUILDING_YIELD_CHANGE', 'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('MONUMENT_TO_THE_GODS_PALACE_FAITH',      'MODIFIER_ALL_CITIES_ADJUST_BUILDING_YIELD_CHANGE', 'CITY_FOLLOWS_PANTHEON_REQUIREMENTS');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('MONUMENT_TO_THE_GODS_PALACE_PRODUCTION', 'BuildingType', 'BUILDING_PALACE'),
('MONUMENT_TO_THE_GODS_PALACE_PRODUCTION', 'YieldType',    'YIELD_PRODUCTION'),
('MONUMENT_TO_THE_GODS_PALACE_PRODUCTION', 'Amount',       '1'),
('MONUMENT_TO_THE_GODS_PALACE_FAITH', 'BuildingType', 'BUILDING_PALACE'),
('MONUMENT_TO_THE_GODS_PALACE_FAITH', 'YieldType',    'YIELD_FAITH'),
('MONUMENT_TO_THE_GODS_PALACE_FAITH', 'Amount',       '2');


INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_GOD_KING', 'MONUMENT_TO_THE_GODS_WONDER_PRODUCTION');
*/

/* not working

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION', 'MODIFIER_ALL_CITIES_ADJUST_WONDER_PRODUCTION', 'CITY_FOLLOWS_PANTHEON_REQUIREMENTS');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION', 'Amount', '15');
*/

/* not working

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION',          'MODIFIER_ALL_PLAYERS_ATTACH_MODIFIER',            'PLAYER_HAS_PANTHEON_REQUIREMENTS'),
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION_MODIFIER', 'MODIFIER_PLAYER_CITIES_ADJUST_WONDER_PRODUCTION', NULL);

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION',          'ModifierId', 'MONUMENT_TO_THE_GODS_WONDER_PRODUCTION_MODIFIER'),
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION_MODIFIER', 'Amount',     '15');
*/

/* not working

--EFFECT_ADJUST_CITY_PRODUCTION_DISTRICT MODIFIER_PLAYER_CITIES_ADJUST_DISTRICT_PRODUCTION_CHANGE
INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION',          'MODIFIER_ALL_PLAYERS_ATTACH_MODIFIER',                       'PLAYER_HAS_PANTHEON_REQUIREMENTS'),
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION_MODIFIER', 'MODIFIER_PLAYER_CITIES_ADJUST_BUILDING_PRODUCTION_MODIFIER', NULL);

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION', 'ModifierId', 'MONUMENT_TO_THE_GODS_WONDER_PRODUCTION_MODIFIER'),
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION_MODIFIER', 'IsWonder', '0'),
('MONUMENT_TO_THE_GODS_WONDER_PRODUCTION_MODIFIER', 'Amount',  '25');
*/



--------------------------------------------------------------
-- BELIEF_ONE_WITH_NATURE (new)
-- One with Nature
-- +1 Faith from each passable Natural Wonder tile within borders. Only Passable - they can be worked!

INSERT INTO Types (Type, Kind) VALUES
('BELIEF_ONE_WITH_NATURE', 'KIND_BELIEF');

INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
('BELIEF_ONE_WITH_NATURE', 'LOC_BELIEF_ONE_WITH_NATURE_NAME', 'LOC_BELIEF_ONE_WITH_NATURE_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_ONE_WITH_NATURE', 'ONE_WITH_NATURE_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('ONE_WITH_NATURE_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('ONE_WITH_NATURE_FAITH_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_ONE_WITH_NATURE');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('ONE_WITH_NATURE_FAITH', 'ModifierId', 'ONE_WITH_NATURE_FAITH_MODIFIER'),
('ONE_WITH_NATURE_FAITH_MODIFIER', 'YieldType', 'YIELD_FAITH'),
('ONE_WITH_NATURE_FAITH_MODIFIER', 'Amount',    '3');

-- Requirement: plot has a passable natural wonder
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType) VALUES ('REQUIREMENTS_ONE_WITH_NATURE', 'REQUIREMENTSET_TEST_ANY');

INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId)
SELECT 'REQUIREMENTS_ONE_WITH_NATURE', 'REQURES_PLOT_HAS_WONDER_'||SUBSTR(FeatureType,9)
FROM Features
WHERE NaturalWonder = 1  AND Impassable = 0;

INSERT INTO Requirements (RequirementId, RequirementType)
SELECT 'REQURES_PLOT_HAS_WONDER_'||SUBSTR(FeatureType,9), 'REQUIREMENT_PLOT_FEATURE_TYPE_MATCHES'
FROM Features
WHERE NaturalWonder = 1  AND Impassable = 0;

INSERT INTO RequirementArguments (RequirementId, Name, Value)
SELECT 'REQURES_PLOT_HAS_WONDER_'||SUBSTR(FeatureType,9), 'FeatureType', FeatureType
FROM Features
WHERE NaturalWonder = 1  AND Impassable = 0;



--------------------------------------------------------------
-- BELIEF_SUN_GOD (new)
-- +2 Faith from Farms over Wheat or Rice

INSERT INTO Types (Type, Kind) VALUES
('BELIEF_SUN_GOD', 'KIND_BELIEF');

INSERT INTO Beliefs (BeliefType, Name, Description, BeliefClassType) VALUES
('BELIEF_SUN_GOD', 'LOC_BELIEF_SUN_GOD_NAME', 'LOC_BELIEF_SUN_GOD_DESCRIPTION', 'BELIEF_CLASS_PANTHEON');

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_SUN_GOD', 'SUN_GOD_FARM_FAITH'),
('BELIEF_SUN_GOD', 'SUN_GOD_RESOURCES_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('SUN_GOD_FARM_FAITH',               'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
--('SUN_GOD_RESOURCES_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'REQUIREMENTS_CITY_FOLLOWS_PANTHEON_ANCIENT'),
('SUN_GOD_RESOURCES_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',          'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('SUN_GOD_FARM_FAITH_MODIFIER',      'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_SUN_GOD_FARM_RESOURCES'),
('SUN_GOD_RESOURCES_FAITH_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_SUN_GOD_RESOURCES');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('SUN_GOD_FARM_FAITH',      'ModifierId', 'SUN_GOD_FARM_FAITH_MODIFIER'),
('SUN_GOD_RESOURCES_FAITH', 'ModifierId', 'SUN_GOD_RESOURCES_FAITH_MODIFIER'),
('SUN_GOD_FARM_FAITH_MODIFIER', 'YieldType', 'YIELD_FAITH'),
('SUN_GOD_FARM_FAITH_MODIFIER', 'Amount',    '2'),
('SUN_GOD_RESOURCES_FAITH_MODIFIER', 'YieldType', 'YIELD_FAITH'),
('SUN_GOD_RESOURCES_FAITH_MODIFIER', 'Amount',    '2');

-- Requirement: plot has a specific resource class
INSERT INTO Requirements (RequirementId, RequirementType)				 VALUES ('REQUIRES_PLOT_HAS_TAG_SUN_GOD',  'REQUIREMENT_PLOT_RESOURCE_TAG_MATCHES');
INSERT INTO RequirementArguments (RequirementId, Name, Value)			 VALUES ('REQUIRES_PLOT_HAS_TAG_SUN_GOD',  'Tag', 'CLASS_SUN_GOD');

-- Requirement: plot has a farm over a resource with a specific tag
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_SUN_GOD_FARM_RESOURCES', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_SUN_GOD_FARM_RESOURCES', 'REQUIRES_PLOT_HAS_FARM'); -- exists
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_SUN_GOD_FARM_RESOURCES', 'REQUIRES_PLOT_HAS_TAG_SUN_GOD');

-- Requirement: plot has a resource with a specific tag
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_SUN_GOD_RESOURCES', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_SUN_GOD_RESOURCES', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_SUN_GOD_RESOURCES', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_SUN_GOD_RESOURCES', 'REQUIRES_PLOT_HAS_TAG_SUN_GOD');



--------------------------------------------------------------
-- BELIEF_DANCE_OF_THE_AURORA
-- +1 Faith from Tundra tiles (no Mountains, as in the original)

DELETE FROM BeliefModifiers WHERE BeliefType = 'BELIEF_DANCE_OF_THE_AURORA'; -- detach original modifiers because they are not scored properly
INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_DANCE_OF_THE_AURORA', 'DANCE_OF_THE_AURORA_TUNDRA_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('DANCE_OF_THE_AURORA_TUNDRA_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('DANCE_OF_THE_AURORA_TUNDRA_FAITH_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_DANCE_OF_THE_AURORA_TUNDRA');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('DANCE_OF_THE_AURORA_TUNDRA_FAITH',          'ModifierId', 'DANCE_OF_THE_AURORA_TUNDRA_FAITH_MODIFIER'),
('DANCE_OF_THE_AURORA_TUNDRA_FAITH_MODIFIER', 'YieldType',  'YIELD_FAITH'),
('DANCE_OF_THE_AURORA_TUNDRA_FAITH_MODIFIER', 'Amount',     '1');

INSERT INTO RequirementSets (RequirementSetId, RequirementSetType) VALUES
('REQUIREMENTS_DANCE_OF_THE_AURORA_TUNDRA', 'REQUIREMENTSET_TEST_ANY');

INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES
('REQUIREMENTS_DANCE_OF_THE_AURORA_TUNDRA', 'REQUIRES_PLOT_HAS_TUNDRA'),
('REQUIREMENTS_DANCE_OF_THE_AURORA_TUNDRA', 'REQUIRES_PLOT_HAS_TUNDRA_HILLS');



--------------------------------------------------------------
--	BELIEF_DESERT_FOLKLORE
-- +1 Faith from Desert tiles

DELETE FROM BeliefModifiers WHERE BeliefType = 'BELIEF_DESERT_FOLKLORE'; -- detach original modifiers because they are not scored properly
INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_DESERT_FOLKLORE', 'DESERT_FOLKLORE_DESERT_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('DESERT_FOLKLORE_DESERT_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('DESERT_FOLKLORE_DESERT_FAITH_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_DESERT_FOLKLORE_DESERT');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('DESERT_FOLKLORE_DESERT_FAITH',          'ModifierId', 'DESERT_FOLKLORE_DESERT_FAITH_MODIFIER'),
('DESERT_FOLKLORE_DESERT_FAITH_MODIFIER', 'YieldType',  'YIELD_FAITH'),
('DESERT_FOLKLORE_DESERT_FAITH_MODIFIER', 'Amount',     '1');

INSERT INTO RequirementSets (RequirementSetId, RequirementSetType) VALUES
('REQUIREMENTS_DESERT_FOLKLORE_DESERT', 'REQUIREMENTSET_TEST_ANY');

INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES
('REQUIREMENTS_DESERT_FOLKLORE_DESERT', 'REQUIRES_PLOT_HAS_DESERT'),
('REQUIREMENTS_DESERT_FOLKLORE_DESERT', 'REQUIRES_PLOT_HAS_DESERT_HILLS');



--------------------------------------------------------------
-- BELIEF_SACRED_PATH
-- +1 Faith from unimproved Rainforest tiles

DELETE FROM BeliefModifiers WHERE BeliefType = 'BELIEF_SACRED_PATH'; -- detach original modifiers because they are not scored properly
INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_SACRED_PATH', 'SACRED_PATH_JUNGLE_FAITH');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('SACRED_PATH_JUNGLE_FAITH',          'MODIFIER_ALL_CITIES_ATTACH_MODIFIER',         'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('SACRED_PATH_JUNGLE_FAITH_MODIFIER', 'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD', 'REQUIREMENTS_SACRED_PATH_JUNGLE'); -- exists

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('SACRED_PATH_JUNGLE_FAITH',          'ModifierId', 'SACRED_PATH_JUNGLE_FAITH_MODIFIER'),
('SACRED_PATH_JUNGLE_FAITH_MODIFIER', 'YieldType',  'YIELD_FAITH'),
('SACRED_PATH_JUNGLE_FAITH_MODIFIER', 'Amount',     '1');

INSERT INTO RequirementSets (RequirementSetId, RequirementSetType) VALUES
('REQUIREMENTS_SACRED_PATH_JUNGLE', 'REQUIREMENTSET_TEST_ALL');

INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES
('REQUIREMENTS_SACRED_PATH_JUNGLE', 'REQUIRES_PLOT_HAS_JUNGLE'), -- exists
('REQUIREMENTS_SACRED_PATH_JUNGLE', 'REQUIRES_PLOT_HAS_NO_IMPROVEMENT');



--------------------------------------------------------------
-- BELIEF_DIVINE_SPARK	DIVINE_SPARK_HOLY_SITE
-- +1 GPP extra in Ancient Era

INSERT INTO BeliefModifiers (BeliefType, ModifierId) VALUES
('BELIEF_DIVINE_SPARK', 'DIVINE_SPARK_HOLY_SITE_ANCIENT'),
('BELIEF_DIVINE_SPARK', 'DIVINE_SPARK_CAMPUS_ANCIENT'),
('BELIEF_DIVINE_SPARK', 'DIVINE_SPARK_THEATER_ANCIENT');

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('DIVINE_SPARK_HOLY_SITE_ANCIENT', 'MODIFIER_ALL_CITIES_ATTACH_MODIFIER', 'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('DIVINE_SPARK_CAMPUS_ANCIENT',    'MODIFIER_ALL_CITIES_ATTACH_MODIFIER', 'CITY_FOLLOWS_PANTHEON_REQUIREMENTS'),
('DIVINE_SPARK_THEATER_ANCIENT',   'MODIFIER_ALL_CITIES_ATTACH_MODIFIER', 'CITY_FOLLOWS_PANTHEON_REQUIREMENTS');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('DIVINE_SPARK_HOLY_SITE_ANCIENT', 'ModifierId', 'DIVINE_SPARK_HOLY_SITE_ANCIENT_MODIFIER'),
('DIVINE_SPARK_CAMPUS_ANCIENT',    'ModifierId', 'DIVINE_SPARK_CAMPUS_ANCIENT_MODIFIER'),
('DIVINE_SPARK_THEATER_ANCIENT',   'ModifierId', 'DIVINE_SPARK_THEATER_ANCIENT_MODIFIER');

-- 2019-06-29 recreate removed in June Patch modifiers

INSERT INTO Modifiers(ModifierId, ModifierType, SubjectRequirementSetId) VALUES
('DIVINE_SPARK_HOLY_SITE_ANCIENT_MODIFIER', 'MODIFIER_SINGLE_CITY_DISTRICTS_ADJUST_GREAT_PERSON_POINTS', 'REQUIREMENTS_DIVINE_SPARK_HOLY_SITE'),
('DIVINE_SPARK_CAMPUS_ANCIENT_MODIFIER',    'MODIFIER_SINGLE_CITY_DISTRICTS_ADJUST_GREAT_PERSON_POINTS', 'REQUIREMENTS_DIVINE_SPARK_CAMPUS'),
('DIVINE_SPARK_THEATER_ANCIENT_MODIFIER',   'MODIFIER_SINGLE_CITY_DISTRICTS_ADJUST_GREAT_PERSON_POINTS', 'REQUIREMENTS_DIVINE_SPARK_THEATER');

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('DIVINE_SPARK_HOLY_SITE_ANCIENT_MODIFIER', 'GreatPersonClassType', 'GREAT_PERSON_CLASS_PROPHET'),
('DIVINE_SPARK_HOLY_SITE_ANCIENT_MODIFIER', 'Amount', '1'),
('DIVINE_SPARK_CAMPUS_ANCIENT_MODIFIER', 'GreatPersonClassType', 'GREAT_PERSON_CLASS_SCIENTIST'),
('DIVINE_SPARK_CAMPUS_ANCIENT_MODIFIER', 'Amount', '1'),
('DIVINE_SPARK_THEATER_ANCIENT_MODIFIER', 'GreatPersonClassType', 'GREAT_PERSON_CLASS_WRITER'),
('DIVINE_SPARK_THEATER_ANCIENT_MODIFIER', 'Amount', '1');

-- Requirement: holy site + ancient
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_DIVINE_SPARK_HOLY_SITE', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_DIVINE_SPARK_HOLY_SITE', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_DIVINE_SPARK_HOLY_SITE', 'REQUIRES_DISTRICT_IS_HOLY_SITE'); -- exists

-- Requirement: campus + ancient
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_DIVINE_SPARK_CAMPUS', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_DIVINE_SPARK_CAMPUS', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_DIVINE_SPARK_CAMPUS', 'REQUIRES_DISTRICT_IS_CAMPUS'); -- exists

-- Requirement: theater square + ancient
INSERT INTO RequirementSets (RequirementSetId, RequirementSetType)		 VALUES ('REQUIREMENTS_DIVINE_SPARK_THEATER', 'REQUIREMENTSET_TEST_ALL');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_DIVINE_SPARK_THEATER', 'REQUIRES_ERA_IS_ANCIENT');
INSERT INTO RequirementSetRequirements (RequirementSetId, RequirementId) VALUES ('REQUIREMENTS_DIVINE_SPARK_THEATER', 'REQUIRES_DISTRICT_IS_THEATER'); -- exists


--------------------------------------------------------------
-- BELIEF_INITIATION_RITES
-- +50 Faith for each Barbarian Outpost cleared. The unit that cleared the Barbarian Outpost heals +100 HP.
-- In Base game only INITIATION_RITES_FAITH_DISPERSAL (INITIATION_RITES_FAITH_DISPERSAL_MODIFIER) is used
-- XP2 adds INITIATION_RITES_HEALING_DISPERSAL which seems to break the scoring
-- Both are BROKEN - entire Pantheon to be removed

/* 2020-06-10 The scoring has been fixed in the May 2020 Patch
   The belief scores now a reasonable 50..150, so there is no reason to remove it.
   
DELETE FROM BeliefModifiers WHERE BeliefType = 'BELIEF_INITIATION_RITES';
DELETE FROM Beliefs WHERE BeliefType = 'BELIEF_INITIATION_RITES';
DELETE FROM Types WHERE Type = 'BELIEF_INITIATION_RITES';

*/
